CRSPLiquidMktCapGrpsCnts: CRSP Stocks Cap Groups Counts

CRSPLiquidMktCapGrpsCntsR Documentation

CRSP Stocks Cap Groups Counts

Description

Biennial counts of bigcap, smallcap, microcap stocks among liquid CRSP database stocks from 1964 to 2018 using weekly returns. Bigcap stocks consist of midcap, largecap, and megacap stocks. For each contiguous two-year interval, liquid stocks are those with no missing returns and at most 4 returns with value 0.

Usage

data(CRSPLiquidMktCapGrpsCnts)

Format

A multivariate xts object

The microcap, smallcap and bigcap groups were defined using the using the 20th and 50th percentiles of the NYSE capitalization data as breakpoints to separate these three market cap groups.

Examples

data(CRSPLiquidMktCapGrpsCnts)
names(CRSPLiquidMktCapGrpsCnts)
dim(CRSPLiquidMktCapGrpsCnts)

PCRA documentation built on July 15, 2026, 9:06 a.m.