Learn R Programming

PCRA (version 1.2.1)

PCRA-package: PCRA: Companion to Portfolio Construction and Risk Analysis

Description

A collection of functions and data sets that support teaching a quantitative finance MS level course on Portfolio Construction and Risk Analysis, and the writing of a textbook for such a course. The package provides several real-world data sets for problem assignments and student projects, including cross-sections of stock data from the Center for Research on Security Prices, LLC (CRSP), corresponding factor exposures from S&P Global, and several S&P 500 data sets.

Arguments

Author

Maintainer: Doug Martin martinrd3d@gmail.com

Authors:

Other contributors: