| getPCRAData | R Documentation |
Downloads stocksCRSPweekly, stocksCRSPdaily
getPCRAData(dataset = "stocksCRSPweekly", cache = TRUE, refresh = FALSE)
dataset |
a valid dataset name (see details) |
cache |
logical variable controlling whether or not to cache the data so that when calling the function for the same dataset it will be loaded from cache rather than re-downloading from the github site |
refresh |
logical variable controlling whether or not to re-download a cached dataset |
The following are valid names of datasets available:
"Details same as for stocksCRSP except now daily"
"Details same as for stocksCRSP except now weekly"
User must install R.cache package
An object of class “data.table”. If the download fails,
e.g., because the internet resource is temporarily unavailable, the
function returns NULL invisibly, with an informative message.
stocksCRSPweekly <- getPCRAData(dataset = "stocksCRSPweekly")
class(stocksCRSPweekly)
names(stocksCRSPweekly)
stocksCRSPdaily <- getPCRAData(dataset = "stocksCRSPdaily")
class(stocksCRSPdaily)
names(stocksCRSPdaily)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.