View source: R/meanReturns4Types.R
| meanReturns4Types | R Documentation |
Computation of arithmetic mean, logarithmic mean, geometric mean, and an approximate geometric mean.
meanReturns4Types(return, robust = FALSE, eff = 0.95)
return |
An xts object or a numeric vector of returns |
robust |
A logical value controlling whether a classical or robust sample mean and standard deviation is computed. Default is FALSE |
eff |
Normal distribution efficiency of RobStatTM function locScaleM() used for computing a robust location estimate |
fourMeans numeric values of the four means in the Description
args(meanReturns4Types)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.