minVarCashRisky: Minimum Variance Portfolio

View source: R/minVarCashRisky.R

minVarCashRiskyR Documentation

Minimum Variance Portfolio

Description

Given a time series of asset returns and risk-free T-Bill returns, a target mean return, and a specification of whether the asset weights are constrained to be long-only, this function compputes the weights of a fully-invested minimum variance portfolio

Usage

minVarCashRisky(returns, mu0, LO = FALSE, bnd = 1000, bndRF = 100)

Arguments

returns

xts multivariate returns object that contains the returns of the risk-free T-Bill in the last column

mu0

Minimum variance portfolio mean return

LO

Logical variable with default FALSE

bnd

Bound on asset weights

bndRF

a bound on the risk-free T-Bill weight

Value

A list of the minimum variance portfolio numeric weights, mean value, volatility, and Sharpe Ratio.

Examples

args(minVarCashRisky)

PCRA documentation built on July 15, 2026, 9:06 a.m.