View source: R/minVarRiskyLO.R
| minVarRiskyLO | R Documentation |
Given a time series of risky asset returns and a target mean return, this function computes the mean and standard deviation of a fully-invested long-only minimum variance portfolio
minVarRiskyLO(returns, mu)
returns |
xts multivariate risky asset returns |
mu |
Portfolio mean return specification |
This function uses the PortfolioAnalytics function optimize.portfolio.R and the PCRA function opt.outputMvoPCRA. For details, see the man pages for those function.
A list containing the weights, mean value, standard deviation and Sharpe ratio, with default names Wgts, Mean, StdDeve, SR
R. Douglas Martin
args(minVarRiskyLO)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.