Learn R Programming

PCRA (version 1.3.1)

psiHuber: Huber psi function

Description

The Huber psi function psi(x) is the derivative of the Huber rho function, with a tuning constant cc that controls the trade-off between robustness toward outliers, and normal distribution estimator efficiency.

Usage

psiHuber(x, cc = 2)

Value

Numeric value of psi(x)

Arguments

x

Numeric argument of psi function

cc

numeric robustness tuning constant

Details

The choice cc = 1.345 results in a 95 distribution efficiency for the Huber location M-estimator. The default value cc = 2.0 is better for EWMA robust filters.

Examples

Run this code
psiHuber(0.5)

Run the code above in your browser using DataLab