stocksCRSPweekly: CRSP weekly stocks data for 294 stocks

stocksCRSPweeklyR Documentation

CRSP weekly stocks data for 294 stocks

Description

CRSP Weekly stocks data for 294 stocks for 1993 to 2015. This dataset is not shipped with the package due to CRAN package size limits. Download it with stocksCRSPweekly <- getPCRAData(dataset = "stocksCRSPweekly").

Format

A data.table object with 82000 observations on 15 variables:

  • Date: type 'Date'.

  • TickerLast: type 'chr'. The ticker as of December 2015

  • Ticker: type 'chr'. Monthly ticker period

  • Company: type 'chr'. The name of company with TickerLast

  • CapGroupLast: type 'chr'. Company market capitalization group as of December 2015, one of: MicroCap, SmallCap, MidCap or LargeCap

  • CapGroup: type 'chr'. Monthly market capitalization group

  • GICS: type 'chr'. 6 digit S&P GICS code

  • Sector: type 'chr'. One of 10 sectors specified by the first two digits of the GICS code

  • Return: type 'num'. Arithmetic stock return from one period to the next in decimal form

  • RetExDiv: type 'num'.

  • Price: type 'num'. Stock price at each time period in decimal form

  • PrcSplitAdj: type 'num'.

  • Ret4WkBill: type 'num'. Return of 4 week Treasury bill

  • Ret13WkBill: type 'num'. Return of 13 week Treasury bill

  • Ret1YrBill: type 'num'. Return of 1 year Treasury bill

  • mktIndexCRSP: type 'num'. CRSP value weighted market return

Unknown

Examples


stocksCRSPweekly <- getPCRAData(dataset = "stocksCRSPweekly")



PCRA documentation built on July 15, 2026, 9:06 a.m.