transferCoef: Transfer Coefficent

View source: R/transferCoef.R

transferCoefR Documentation

Transfer Coefficent

Description

Computes the transfer coefficient (TF), which measures the reduction in mean excess return of an MV portfolio with weights constraint relative to the mean excess return of an unconstrained MV portfolio. This description also holds with portfolios mean returns replaced by Sharpe ratios.

Usage

transferCoef(returns, wtVec)

Arguments

returns

An xts multivariate returns object that contains the returns of the risk-free T-Bill in the last column

wtVec

The weight vector of a constrained MV portfolio

Value

Numeric value of the TC

Examples

args(transferCoef)

PCRA documentation built on July 15, 2026, 9:06 a.m.