update_dev_pkg: Update to Developer version on Github that have access to...

View source: R/updateDevPkg.R

update_dev_pkgR Documentation

Update to Developer version on Github that have access to additional functions and data

Description

Update to Developer version on Github that have access to additional functions and data

Usage

update_dev_pkg(
  pkg = "PCRA",
  repo = "https://github.com/robustport/PCRA",
  field = "Version",
  lib = NULL
)

Arguments

pkg

Default to "PCRA" package name.

repo

Default to "https://github.com/robustport/PCRA"

field

Default to "Version" field under Package Description file.

lib

library path where the package would be installed.


PCRA documentation built on July 15, 2026, 9:06 a.m.