Learn R Programming

PCRA (version 1.3.1)

CRSPLiquidMktCapGrpsCnts: CRSP Stocks Cap Groups Counts

Description

Biennial counts of bigcap, smallcap, microcap stocks among liquid CRSP database stocks from 1964 to 2018 using weekly returns. Bigcap stocks consist of midcap, largecap, and megacap stocks. For each contiguous two-year interval, liquid stocks are those with no missing returns and at most 4 returns with value 0.

Usage

data(CRSPLiquidMktCapGrpsCnts)

Arguments

Format

A multivariate xts object

Examples

Run this code
data(CRSPLiquidMktCapGrpsCnts)
names(CRSPLiquidMktCapGrpsCnts)
dim(CRSPLiquidMktCapGrpsCnts)

Run the code above in your browser using DataLab