Learn R Programming

PCRA (version 1.3.1)

minVarRiskyLO: Title Minimum Variance Long-Only Risky Assets Portfolio

Description

Given a time series of risky asset returns and a target mean return, this function computes the mean and standard deviation of a fully-invested long-only minimum variance portfolio

Usage

minVarRiskyLO(returns, mu)

Value

A list containing the weights, mean value, standard deviation and Sharpe ratio, with default names Wgts, Mean, StdDeve, SR

Arguments

returns

xts multivariate risky asset returns

mu

Portfolio mean return specification

Author

R. Douglas Martin

Details

This function uses the PortfolioAnalytics function optimize.portfolio.R and the PCRA function opt.outputMvoPCRA. For details, see the man pages for those function.

Examples

Run this code
args(minVarRiskyLO)

Run the code above in your browser using DataLab