| to_monthly | R Documentation |
to_monthly will convert daily returns to monthly returns.
to_monthly(daily, index_last = TRUE)
daily |
An xts object of daily returns. |
index_last |
Controls whether the return date label will fall on the month end date provided in the dataset (usually the final trading date of the month in most financial data sets) or the calendar month end date (potentially a non-trading date). Regardless, the returns are identical under two scenarios, but the date may differ for the "month end". |
These will be added
monthly
args(to_monthly)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.