Learn R Programming

PCRA (version 1.3.1)

to_monthly: Function to convert from daily to weekly returns.

Description

to_monthly will convert daily returns to monthly returns.

Usage

to_monthly(daily, index_last = TRUE)

Value

monthly

Arguments

daily

An xts object of daily returns.

index_last

Controls whether the return date label will fall on the month end date provided in the dataset (usually the final trading date of the month in most financial data sets) or the calendar month end date (potentially a non-trading date). Regardless, the returns are identical under two scenarios, but the date may differ for the "month end".

Details

These will be added

Examples

Run this code
args(to_monthly)

Run the code above in your browser using DataLab