| transferCoef | R Documentation |
Computes the transfer coefficient (TF), which measures the reduction in mean excess return of an MV portfolio with weights constraint relative to the mean excess return of an unconstrained MV portfolio. This description also holds with portfolios mean returns replaced by Sharpe ratios.
transferCoef(returns, wtVec)
returns |
An xts multivariate returns object that contains the returns of the risk-free T-Bill in the last column |
wtVec |
The weight vector of a constrained MV portfolio |
Numeric value of the TC
args(transferCoef)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.