Learn R Programming

PCRA (version 1.3.1)

transferCoef: Transfer Coefficent

Description

Computes the transfer coefficient (TF), which measures the reduction in mean excess return of an MV portfolio with weights constraint relative to the mean excess return of an unconstrained MV portfolio. This description also holds with portfolios mean returns replaced by Sharpe ratios.

Usage

transferCoef(returns, wtVec)

Value

Numeric value of the TC

Arguments

returns

An xts multivariate returns object that contains the returns of the risk-free T-Bill in the last column

wtVec

The weight vector of a constrained MV portfolio

Examples

Run this code
args(transferCoef)

Run the code above in your browser using DataLab