Learn R Programming

PCRA (version 1.3.1)

update_dev_pkg: Update to Developer version on Github that have access to additional functions and data

Description

Update to Developer version on Github that have access to additional functions and data

Usage

update_dev_pkg(
  pkg = "PCRA",
  repo = "https://github.com/robustport/PCRA",
  field = "Version",
  lib = NULL
)

Arguments

pkg

Default to "PCRA" package name.

repo

Default to "https://github.com/robustport/PCRA"

field

Default to "Version" field under Package Description file.

lib

library path where the package would be installed.